@@ -7,14 +7,11 @@
  */
 
 /*
- * Win32 (Windows NT and Windows 95) machine-dependent things.
+ * Win32 machine-dependent things.
  */
 
 #include "os_dos.h"		// common MS-DOS and Win32 stuff
-// cproto fails on missing include files
-#ifndef PROTO
-# include <direct.h>		// for _mkdir()
-#endif
+#include <direct.h>		// for _mkdir()
 
 #define BINARY_FILE_IO
 #define USE_EXE_NAME		// use argv[0] for $VIM
@@ -25,7 +22,6 @@
 #ifndef HAVE_MATH_H
 # define HAVE_MATH_H
 #endif
-#define HAVE_STRCSPN
 #ifndef __GNUC__
 #define HAVE_STRICMP
 #define HAVE_STRNICMP
@@ -84,19 +80,18 @@
 #ifndef COBJMACROS
 # define COBJMACROS	// For OLE: Enable "friendlier" access to objects
 #endif
-#ifndef PROTO
+
 // Must include winsock2.h before windows.h since it conflicts with winsock.h
 // (included in windows.h).
-# include <winsock2.h>
-# include <ws2tcpip.h>
-# include <windows.h>
+#include <winsock2.h>
+#include <ws2tcpip.h>
+#include <windows.h>
 
 // Weird: rpcndr.h defines "small" to "char", which causes trouble
 #undef small
 
-# ifndef SM_CXPADDEDBORDER
-#  define SM_CXPADDEDBORDER     92
-# endif
+#ifndef SM_CXPADDEDBORDER
+# define SM_CXPADDEDBORDER     92
 #endif
 
 typedef void (*sighandler_T)(int, int);
